==> qtjambi-xmlpatterns-5.15.17-sources.jar: io/qt/xmlpatterns/QXmlNamePool.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Table of shared strings referenced by instances of QXmlName</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html">QXmlNamePool</a></code></p>
 */
public class QXmlNamePool extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool">QXmlNamePool::<wbr>QXmlNamePool()</a></code></p>
     */
    public QXmlNamePool(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlNamePool instance);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool-1">QXmlNamePool::<wbr>QXmlNamePool(QXmlNamePool)</a></code></p>
     */
    public QXmlNamePool(io.qt.xmlpatterns.@NonNull QXmlNamePool other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlNamePool instance, io.qt.xmlpatterns.QXmlNamePool other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html#operator-eq">QXmlNamePool::<wbr>operator=(QXmlNamePool)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xmlpatterns.@NonNull QXmlNamePool other){
        assign_native_cref_QXmlNamePool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QXmlNamePool(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QXmlNamePool,<wbr>QXmlNamePool)</code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.xmlpatterns.@NonNull QXmlNamePool arg2){
        return operator_equal_native_cref_QXmlNamePool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QXmlNamePool(long __this__nativeId, long arg2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QXmlNamePool(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QXmlNamePool,<wbr>QXmlNamePool)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.xmlpatterns.QXmlNamePool) {
            return operator_equal((io.qt.xmlpatterns.QXmlNamePool) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QXmlNamePool)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QXmlNamePool clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QXmlNamePool clone_native(long __this_nativeId);
}

==> qtjambi-xmlpatterns-5.15.18-sources.jar: io/qt/xmlpatterns/QXmlNamePool.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Table of shared strings referenced by instances of QXmlName</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html">QXmlNamePool</a></code></p>
 */
public class QXmlNamePool extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool">QXmlNamePool::<wbr/>QXmlNamePool()</a></code></p>
     */
    public QXmlNamePool(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlNamePool instance);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html#QXmlNamePool-1">QXmlNamePool::<wbr/>QXmlNamePool(QXmlNamePool)</a></code></p>
     */
    public QXmlNamePool(io.qt.xmlpatterns.@NonNull QXmlNamePool other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlNamePool instance, io.qt.xmlpatterns.QXmlNamePool other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qxmlnamepool.html#operator-eq">QXmlNamePool::<wbr/>operator=(QXmlNamePool)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xmlpatterns.@NonNull QXmlNamePool other){
        assign_native_cref_QXmlNamePool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QXmlNamePool(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QXmlNamePool,<wbr/>QXmlNamePool)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.xmlpatterns.@NonNull QXmlNamePool arg2){
        return equals_native_cref_QXmlNamePool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QXmlNamePool(long __this__nativeId, long arg2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QXmlNamePool(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QXmlNamePool,<wbr/>QXmlNamePool)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.xmlpatterns.QXmlNamePool) {
            return equals((io.qt.xmlpatterns.QXmlNamePool) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QXmlNamePool)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QXmlNamePool clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QXmlNamePool clone_native(long __this_nativeId);
}
